@@ -14,4 +14,4 @@ def worklet_entry(args, cijoe, step):
 
     guest = Guest(cijoe, cijoe.config)
 
-    return guest.cloudinit()
+    return guest.init_using_cloudimg()
